Improve this doc View Source

Specify custom behavior on focus event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as attribute:

      <window, input, select, textarea, a
        ng-focus="">
      ...
      </window, input, select, textarea, a>

### Arguments

Param | Type | Details
--- | --- | ---
ngFocus | expression | Expression to evaluate upon focus. (Event object is available as `$event`)

## Example

See ngClick